@@ -1,12 +1,13 @@
 use crate::coco_struct::ClassInfo;
 use std::collections::HashMap;
+use crate::ParseOption;
 use crate::render::{render_member, render_method};
 
 /// Render classes info to string
 pub struct MermaidRender;
 
 impl MermaidRender {
-    pub fn render(classes: &Vec<ClassInfo>) -> String {
+    pub fn render(classes: &Vec<ClassInfo>, parse_option: &ParseOption) -> String {
         let space = "    ";
         let mut rendered: Vec<String> = vec![];
         let mut deps: Vec<String> = vec![];
@@ -20,7 +21,10 @@ impl MermaidRender {
             let mut dep_map: HashMap<String, String> = HashMap::default();
 
             let members = render_member(&clazz, &mut dep_map, space);
-            let methods = render_method(&clazz, &mut dep_map, space);
+            let mut methods = vec![];
+            if !parse_option.field_only {
+                methods = render_method(&clazz, &mut dep_map, space);
+            }
 
             let content = format!("{}{}", members.join(""), methods.join(""));
             let class_field = clazz.name.clone();
